from setuptools import find_packages, setup

# Read requirements using context manager
with open("requirements.txt", encoding="utf-8") as f:
    requirements = [line.strip() for line in f if line.strip() and not line.startswith("#")]

setup(
    name="qz",
    version="0.1",
    packages=find_packages(),
    install_requires=requirements,
)
